Package: ggthemes
Version: 5.1.0
Title: Extra Themes, Scales and Geoms for 'ggplot2'
Authors@R: c(person("Jeffrey B.", "Arnold", role = c("aut", "cre"),
    email = "jeffrey.arnold@gmail.com", 
    comment = "<https://orcid.org/0000-0001-9953-3904>"),
    person("Gergely", "Daroczi", role = "ctb"),
    person("Bo", "Werth", role = "ctb"),
    person("Brian", "Weitzner", role = "ctb"),
    person("Joshua", "Kunst", role = "ctb"),
    person("Baptise", "Auguie", role = "ctb"),
    person("Bob", "Rudis", role = "ctb"),
    person("Hadley", "Wickham", role = c("ctb"),
    comment = "Code from the ggplot2 package."),
    person("Justin",  "Talbot", role = "ctb",
    comment = "Code from the labeling package"),
    person("Joshua", "London", role = "ctb"))
Depends: R (>= 3.3.0)
Imports: ggplot2 (>= 3.0.0), graphics, grid, lifecycle, methods, purrr,
        scales, stringr, tibble
Suggests: dplyr, covr, extrafont, glue, knitr, lattice, lintr, maps,
        mapproj, pander, quantreg, rlang, rmarkdown, spelling, testthat
        (>= 3.2.0), tidyr, vdiffr, withr
Description: Some extra themes, geoms, and scales for 'ggplot2'.
    Provides 'ggplot2' themes and scales that replicate the look of plots
    by Edward Tufte, Stephen Few, 'Fivethirtyeight', 'The Economist', 'Stata',
    'Excel', and 'The Wall Street Journal', among others.
    Provides 'geoms' for Tufte's box plot and range frame.
License: GPL-2
URL: https://jrnold.github.io/ggthemes/,
        https://github.com/jrnold/ggthemes
BugReports: https://github.com/jrnold/ggthemes/issues
RoxygenNote: 7.3.1
LazyData: true
Language: en-US
Encoding: UTF-8
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2024-02-09 17:47:25 UTC; jrnold
Author: Jeffrey B. Arnold [aut, cre] (<https://orcid.org/0000-0001-9953-3904>),
  Gergely Daroczi [ctb],
  Bo Werth [ctb],
  Brian Weitzner [ctb],
  Joshua Kunst [ctb],
  Baptise Auguie [ctb],
  Bob Rudis [ctb],
  Hadley Wickham [ctb] (Code from the ggplot2 package.),
  Justin Talbot [ctb] (Code from the labeling package),
  Joshua London [ctb]
Maintainer: Jeffrey B. Arnold <jeffrey.arnold@gmail.com>
Repository: CRAN
Date/Publication: 2024-02-10 00:30:02 UTC
Built: R 4.6.0; ; 2026-07-20 11:11:24 UTC; unix
