Package: ggthemes
Version: 3.4.0
Title: Extra Themes, Scales and Geoms for 'ggplot2'
Authors@R: c(person("Jeffrey B.", "Arnold", role = c("aut", "cre"),
    email = "jeffrey.arnold@gmail.com"),
    person("Gergely", "Daroczi", role = "ctb"),
    person("Bo", "Werth", role = "ctb"),
    person("Brian", "Weitzner", role = "ctb"),
    person("Joshua", "Kunst", role = "ctb"),
    person("Baptise", "Auguie", role = "ctb"),
    person("Bob", "Rudis", role = "ctb"),
    person("Hadley", "Wickham", role = c("ctb", "cph"),
    comment = "Code from the ggplot2 package."),
    person("Justin",  "Talbot", role = "ctb",
    comment = "Code from the labeling package"),
    person("Joshua", "London", role = "ctb"))
Depends: R (>= 3.0.0),
Imports: assertthat, colorspace, ggplot2 (>= 2.2.0), graphics, grid,
        methods, scales
Suggests: extrafont, knitr, lintr, maps, mapproj, pander, plyr,
        reshape2, rmarkdown, testthat, tidyverse
VignetteBuilder: knitr
Description: Some extra themes, geoms, and scales for 'ggplot2'.
    Provides 'ggplot2' themes and scales that replicate the look of plots
    by Edward Tufte, Stephen Few, 'Fivethirtyeight', 'The Economist', 'Stata',
    'Excel', and 'The Wall Street Journal', among others.
    Provides 'geoms' for Tufte's box plot and range frame.
License: GPL-2
URL: http://github.com/jrnold/ggthemes
BugReports: http://github.com/jrnold/ggthemes
Collate: 'banking.R' 'base.R' 'calc.R' 'canva.R' 'colorblind.R'
        'economist.R' 'excel.R' 'few.R' 'ggthemes-data.R'
        'ggthemes-package.R' 'fivethirtyeight.R' 'gdocs.R'
        'geom-rangeframe.R' 'geom-tufteboxplot.R' 'hc.R' 'igray.R'
        'pander.R' 'ptol.R' 'scale-tufte.R' 'shapes.R' 'show.R'
        'solarized.R' 'stat-fivenumber.R' 'stata.R' 'tableau.R'
        'theme-foundation.R' 'theme-map.R' 'theme-solid.R' 'tufte.R'
        'utils.R' 'wsj.R'
RoxygenNote: 6.0.1
LazyData: true
NeedsCompilation: no
Packaged: 2017-02-19 09:14:16 UTC; jrnold
Author: Jeffrey B. Arnold [aut, cre],
  Gergely Daroczi [ctb],
  Bo Werth [ctb],
  Brian Weitzner [ctb],
  Joshua Kunst [ctb],
  Baptise Auguie [ctb],
  Bob Rudis [ctb],
  Hadley Wickham [ctb, cph] (Code from the ggplot2 package.),
  Justin Talbot [ctb] (Code from the labeling package),
  Joshua London [ctb]
Maintainer: Jeffrey B. Arnold <jeffrey.arnold@gmail.com>
Repository: CRAN
Date/Publication: 2017-02-19 10:53:38
Built: R 3.3.2; ; 2017-09-17 21:36:06 UTC; windows
