# Generated by roxygen2: do not edit by hand

export(GeomRangeFrame)
export(GeomTufteboxplot)
export(StatFivenumber)
export(bank_slopes)
export(calc_pal)
export(calc_shape_pal)
export(canva_pal)
export(circlefill_shape_pal)
export(cleveland_shape_pal)
export(colorblind_pal)
export(economist_pal)
export(excel_pal)
export(extended_range_breaks)
export(extended_range_breaks_)
export(few_pal)
export(fivethirtyeight_pal)
export(gdocs_pal)
export(geom_rangeframe)
export(geom_tufteboxplot)
export(ggthemes_data)
export(hc_pal)
export(palette_pander)
export(ptol_pal)
export(scale_color_calc)
export(scale_color_canva)
export(scale_color_colorblind)
export(scale_color_continuous_tableau)
export(scale_color_economist)
export(scale_color_excel)
export(scale_color_few)
export(scale_color_fivethirtyeight)
export(scale_color_gdocs)
export(scale_color_gradient2_tableau)
export(scale_color_gradient_tableau)
export(scale_color_hc)
export(scale_color_pander)
export(scale_color_ptol)
export(scale_color_solarized)
export(scale_color_stata)
export(scale_color_tableau)
export(scale_color_wsj)
export(scale_colour_calc)
export(scale_colour_canva)
export(scale_colour_colorblind)
export(scale_colour_economist)
export(scale_colour_excel)
export(scale_colour_few)
export(scale_colour_fivethirtyeight)
export(scale_colour_gdocs)
export(scale_colour_gradient2_tableau)
export(scale_colour_gradient_tableau)
export(scale_colour_hc)
export(scale_colour_pander)
export(scale_colour_ptol)
export(scale_colour_solarized)
export(scale_colour_stata)
export(scale_colour_tableau)
export(scale_colour_wsj)
export(scale_fill_calc)
export(scale_fill_canva)
export(scale_fill_colorblind)
export(scale_fill_continuous_tableau)
export(scale_fill_economist)
export(scale_fill_excel)
export(scale_fill_few)
export(scale_fill_fivethirtyeight)
export(scale_fill_gdocs)
export(scale_fill_gradient2_tableau)
export(scale_fill_gradient_tableau)
export(scale_fill_hc)
export(scale_fill_pander)
export(scale_fill_ptol)
export(scale_fill_solarized)
export(scale_fill_stata)
export(scale_fill_tableau)
export(scale_fill_wsj)
export(scale_linetype_stata)
export(scale_shape_calc)
export(scale_shape_circlefill)
export(scale_shape_cleveland)
export(scale_shape_stata)
export(scale_shape_tableau)
export(scale_shape_tremmel)
export(show_linetypes)
export(show_shapes)
export(smart_digits)
export(smart_digits_format)
export(solarized_pal)
export(stat_fivenumber)
export(stata_linetype_pal)
export(stata_pal)
export(stata_shape_pal)
export(tableau_color_pal)
export(tableau_div_gradient_pal)
export(tableau_seq_gradient_pal)
export(tableau_shape_pal)
export(theme_base)
export(theme_calc)
export(theme_economist)
export(theme_economist_white)
export(theme_excel)
export(theme_few)
export(theme_fivethirtyeight)
export(theme_foundation)
export(theme_gdocs)
export(theme_hc)
export(theme_igray)
export(theme_map)
export(theme_pander)
export(theme_par)
export(theme_solarized)
export(theme_solarized_2)
export(theme_solid)
export(theme_stata)
export(theme_tufte)
export(theme_wsj)
export(tremmel_shape_pal)
export(wsj_pal)
import(assertthat)
import(colorspace)
import(ggplot2)
import(stats)
import(utils)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(grid,gList)
importFrom(grid,gTree)
importFrom(grid,gpar)
importFrom(grid,grobName)
importFrom(grid,grobTree)
importFrom(grid,segmentsGrob)
importFrom(methods,as)
importFrom(methods,hasArg)
importFrom(scales,div_gradient_pal)
importFrom(scales,manual_pal)
importFrom(scales,seq_gradient_pal)
