

library("ggplot2")
p <- ggplot(mtcars) +
     geom_point(aes(x = wt, y = mpg, colour=factor(gear))) +
     facet_wrap(~am) +
     ggtitle('Diamond Prices')
p + scale_colour_wsj('colors6', '') + theme_wsj()
# Use a gray background instead#'
p + scale_colour_wsj('colors6', '') + theme_wsj(color = "gray")



