---
title: Introduction to ggthemes
author: Jeffrey B. Arnold
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Introduction to ggthemes}
  %\VignetteEngine{knitr::rmarkdown}
  \usepackage[utf8](inputenc)
---

```{r header,echo=FALSE,results='hide'}
library("knitr")
opts_chunk$set(fig.width = 5.25, fig.height = 3.75, cache=FALSE)
```

# ggthemes Package

```{r child='children/intro.Rmd'}
```

```{r child='children/examples.Rmd'}
```
